# =====================================
# generator=datazen
# version=3.1.4
# hash=e06df2a290504acc295de3cca0c95e06
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A tool for working with scalable vector graphics."
PKG_NAME = "svgen"
VERSION = "0.7.6"
